import os

# Make callers be able to `from abejacli.config import Config`
from abejacli.configuration import (CONFIG_FILE_PATH,  # noqa: F401
                                    ROOT_DIRECTORY)
from abejacli.configuration.loader import ConfigLoader
from abejacli.exceptions import InvalidConfigException

SUCCESS_EXITCODE = 0
ERROR_EXITCODE = 1

LOG_DIRECTORY = os.path.join(os.path.expanduser('~'), '.abeja', 'log')
LOG_FILE_PATH = os.path.join(LOG_DIRECTORY, 'abejacli.log')

ABEJA_API_URL = os.environ.get('ABEJA_API_URL', 'https://api.abeja.io')
SAMPLE_MODEL_PATH = os.environ.get(
    'SAMPLE_MODEL_PATH',
    'https://s3-ap-northeast-1.amazonaws.com/abeja-platform-config-prod'
)
STDERROR_LOG_LEVEL = os.environ.get('LOG_LEVEL', 'ERROR')
DATALAKE_ITEMS_PER_PAGE = int(os.environ.get('DATALAKE_ITEMS_PER_PAGE', 100))
HTTP_READ_CHUNK_SIZE = int(os.environ.get('HTTP_READ_CHUNK_SIZE', 1024))
FILE_READ_CHUNK_SIZE = int(os.environ.get('FILE_READ_CHUNK_SIZE', 8192))
JOB_WORKER_THREAD_NUM = int(os.environ.get('JOB_WORKER_THREAD_NUM', 10))
PLATFORM_REQUEST_TIMEOUT_SECONDS = int(
    os.environ.get('PLATFORM_REQUEST_TIMEOUT_SECONDS', 300))

SERVICE_API_TIMEOUT = 90

DATASET_CHUNK_SIZE = 500

ENV_VAR_KEY_FORMAT = r'^[a-zA-Z_][a-zA-Z0-9_]*$'
DATASET_VAR_KEY_FORMAT = r'^[a-zA-Z_][a-zA-Z0-9_]*$'

TRIGGER_DEFAULT_RETRY_COUNT = 5
RUN_DEFAULT_RETRY_COUNT = 5

DEFAULT_EXCLUDE_FILES = ['.git']

RUN_LOCAL_COMMAND_V1 = ['/bin/sh', '-c', 'abeja-model run']
RUN_LOCAL_COMMAND_V2 = ['/bin/sh', '-c', 'platform-model-proxy run']

# Configurations
CONFIG = None
ABEJA_PLATFORM_USER_ID = None
ABEJA_PLATFORM_TOKEN = None
ORGANIZATION_NAME = None
ORGANIZATION_ENDPOINT = None

# For backward compatibility, CONFIG must be a plain dictionary.
try:
    CONFIG = ConfigLoader().load().asdict()
    ABEJA_PLATFORM_USER_ID = CONFIG['abeja-platform-user']
    ABEJA_PLATFORM_TOKEN = CONFIG['personal-access-token']
    ORGANIZATION_NAME = CONFIG['organization-name']
except InvalidConfigException:
    CONFIG = None

ORGANIZATION_ENDPOINT = "{}/organizations/{}".format(
    ABEJA_API_URL, ORGANIZATION_NAME)
protocol, fqdn = ABEJA_API_URL.split('://')
WEB_API_ENDPOINT = '{}://{}.{}'.format(protocol, ORGANIZATION_NAME, fqdn)
